==> qore-1.17.0.tar.bz2: qore-1.17.0/docs/modules/SalesforceRestClient/html/namespace_salesforce_rest_client.js <==
var namespace_salesforce_rest_client =
[
    [ "SalesforceRestClient", "class_salesforce_rest_client_1_1_salesforce_rest_client.html", "class_salesforce_rest_client_1_1_salesforce_rest_client" ],
    [ "SalesforceRestConnection", "class_salesforce_rest_client_1_1_salesforce_rest_connection.html", "class_salesforce_rest_client_1_1_salesforce_rest_connection" ],
    [ "BulkJobContentTypes", "namespace_salesforce_rest_client.html#a395a3094187bfeca16c1848937dfcc61", null ],
    [ "BulkJobCsv", "group__bulkjob__contenttypes.html#ga1b07925839976ba7ae9946a32dfc0a85", null ],
    [ "BulkJobDelete", "group__bulkjob__operations.html#gaaaf495895fd00f35469f10590c02500a", null ],
    [ "BulkJobInsert", "group__bulkjob__operations.html#gaba54de28772d5ec7c5a03a68e6934cc0", null ],
    [ "BulkJobJson", "group__bulkjob__contenttypes.html#ga49f1652c5a11d8e114b664231c111b0f", null ],
    [ "BulkJobOperations", "namespace_salesforce_rest_client.html#a846b56aff21c82f804b845aafea51f82", null ],
    [ "BulkJobQuery", "group__bulkjob__operations.html#ga5218f87c25b8e861ca9d918065eb51bf", null ],
    [ "BulkJobUpdate", "group__bulkjob__operations.html#gafa491a416efd1871da31c901b7434ebc", null ],
    [ "BulkJobUpsert", "group__bulkjob__operations.html#ga769d5314fc8dd3a013698a6239bbceb5", null ],
    [ "BulkJobXml", "group__bulkjob__contenttypes.html#ga297d405419a8a774699fe7e12cc4d9b1", null ],
    [ "BulkJobZipCsv", "group__bulkjob__contenttypes.html#ga0e2e96166c13b4c16160f5cf2124fcf8", null ],
    [ "BulkJobZipJson", "group__bulkjob__contenttypes.html#gac6f148a4bde5d36fd206acbcf9e9498c", null ],
    [ "BulkJobZipXml", "group__bulkjob__contenttypes.html#gaeadd6e53fa5bca10b976c529c0075717", null ]
];

==> qore-2.2.0.tar.bz2: qore-2.2.0/docs/modules/SalesforceRestClient/html/namespace_salesforce_rest_client.js <==
var namespace_salesforce_rest_client =
[
    [ "SalesforceRestClient", "class_salesforce_rest_client_1_1_salesforce_rest_client.html", "class_salesforce_rest_client_1_1_salesforce_rest_client" ],
    [ "SalesforceRestConnection", "class_salesforce_rest_client_1_1_salesforce_rest_connection.html", "class_salesforce_rest_client_1_1_salesforce_rest_connection" ],
    [ "SalesforceRestPingPollOperation", "class_salesforce_rest_client_1_1_salesforce_rest_ping_poll_operation.html", "class_salesforce_rest_client_1_1_salesforce_rest_ping_poll_operation" ],
    [ "BulkJobContentTypes", "namespace_salesforce_rest_client.html#a395a3094187bfeca16c1848937dfcc61", null ],
    [ "BulkJobCsv", "group__bulkjob__contenttypes.html#ga1b07925839976ba7ae9946a32dfc0a85", null ],
    [ "BulkJobDelete", "group__bulkjob__operations.html#gaaaf495895fd00f35469f10590c02500a", null ],
    [ "BulkJobInsert", "group__bulkjob__operations.html#gaba54de28772d5ec7c5a03a68e6934cc0", null ],
    [ "BulkJobJson", "group__bulkjob__contenttypes.html#ga49f1652c5a11d8e114b664231c111b0f", null ],
    [ "BulkJobOperations", "namespace_salesforce_rest_client.html#a846b56aff21c82f804b845aafea51f82", null ],
    [ "BulkJobQuery", "group__bulkjob__operations.html#ga5218f87c25b8e861ca9d918065eb51bf", null ],
    [ "BulkJobUpdate", "group__bulkjob__operations.html#gafa491a416efd1871da31c901b7434ebc", null ],
    [ "BulkJobUpsert", "group__bulkjob__operations.html#ga769d5314fc8dd3a013698a6239bbceb5", null ],
    [ "BulkJobXml", "group__bulkjob__contenttypes.html#ga297d405419a8a774699fe7e12cc4d9b1", null ],
    [ "BulkJobZipCsv", "group__bulkjob__contenttypes.html#ga0e2e96166c13b4c16160f5cf2124fcf8", null ],
    [ "BulkJobZipJson", "group__bulkjob__contenttypes.html#gac6f148a4bde5d36fd206acbcf9e9498c", null ],
    [ "BulkJobZipXml", "group__bulkjob__contenttypes.html#gaeadd6e53fa5bca10b976c529c0075717", null ]
];
